@@ -98,7 +98,8 @@ gkm_keyring_editor_new (const char *keyring_name)
 
   editor = g_object_new (GKM_TYPE_KEYRING_EDITOR, NULL);
 
-  gkm_keyring_editor_set_keyring_name (editor, keyring_name);
+  if (keyring_name)
+    gkm_keyring_editor_set_keyring_name (editor, keyring_name);
   
   return G_OBJECT (editor);
 }
@@ -139,7 +140,7 @@ keyring_item_type_text_from_enum (GnomeKeyringItemType type)
         text = _("Note");
         break;
       default:
-        g_warning (_("Unknown keyring item type: %d"), type);
+        g_warning ("Unknown keyring item type: %d", type);
         text = "";
         break;
     }
@@ -361,7 +362,7 @@ acl_saved_callback (GnomeKeyringResult result,
 
 /*   if (!gtk_tree_row_reference_valid (data->row)) */
 /*     { */
-/*       g_warning (_("A row disappeared while we were waiting for the data...")); */
+/*       g_warning ("A row disappeared while we were waiting for the data..."); */
 
 /*       return; */
 /*     } */
@@ -388,7 +389,10 @@ gkm_keyring_editor_set_acl (GKMKeyringEditor *self,
 			      acl_saved_callback,
 			      data, g_free);
 
-  gnome_keyring_acl_free (acl);
+  /* FIXME: This is leaking the acl here. Previous 
+     gnome_keyring_acl_free (acl) made of course crash it.
+     we should add the acl to the data and free it on the destroy
+     callback, but that is also crashing. Need investigation */
 }
 
 /********************************************************
@@ -916,14 +920,14 @@ update_keyring_item_info_worker_callback (GnomeKeyringResult             result,
   
   if (result != GNOME_KEYRING_RESULT_OK) 
     {
-      g_warning (_("Failed to get keyring info."));
+      g_warning ("Failed to get keyring info.");
 
       return;
     }
 
   if (!gtk_tree_row_reference_valid (data->row))
     {
-      g_warning (_("A row disappeared while we were waiting for the data..."));
+      g_warning ("A row disappeared while we were waiting for the data...");
 
       return;
     }
